@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2019 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2020 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -17,6 +17,7 @@
 
 
 
+
  dtheta.deta <-
   function(theta,
            link = "identitylink",
@@ -42,8 +43,8 @@
   earg[["deriv"]] <- 1  # New
 
 
-  do.call(what = function.name, args = earg)
-}
+  do.call(function.name, earg)
+}  # dtheta.deta 
 
 
 
@@ -64,7 +65,8 @@
 
   function.name2 <- attr(earg, "function.name")
   if (length(function.name2) && function.name != function.name2)
-    warning("apparent conflict in name of link function in D2theta.deta2")
+    warning("apparent conflict in name of link function in ",
+            "D2theta.deta2()")
 
   earg[["theta"]] <- theta  # New data
 
@@ -75,8 +77,9 @@
 
   earg[["deriv"]] <- 2  # New
 
-  do.call(what = function.name, args = earg)
-}
+  do.call(function.name, earg)
+}  # d2theta.deta2
+
 
 
 
@@ -99,8 +102,8 @@
     earg$inverse <- TRUE
 
   earg[["deriv"]] <- 3  # New
-  do.call(what = function.name, args = earg)
-}
+  do.call(function.name, earg)
+}  # d3theta.deta3
 
 
 
@@ -120,8 +123,10 @@
 
   earg[["theta"]] <- theta  # New data
 
-  do.call(what = function.name, args = earg)
-}
+  do.call(function.name, earg)
+}  # theta2eta
+
+
 
 
 
@@ -129,7 +134,10 @@
  eta2theta <-
   function(theta,  # This is really eta.
            link = "identitylink",
-           earg = list(theta = NULL)) {
+           earg = list(theta = NULL),
+           special.fun = "multilogitlink",
+           delete.coln = TRUE  # Only for "multilogitlink"
+           ) {
 
 
   orig.earg <- earg
@@ -148,7 +156,6 @@
 
 
 
-
   llink <- length(link)
 
   if (llink != length(earg))
@@ -156,59 +163,78 @@
          "length of argument 'earg'")
   if (llink == 0)
     stop("length(earg) == 0 not allowed")
-
-
   if (llink == 1) {  # ,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,
 
 
     if (is.list(earg[[1]]))
       earg <- earg[[1]]
 
-    function.name  <- link
+    function.name  <- link  # First chance
 
     function.name2 <- attr(earg, "function.name")  # May be, e.g., NULL
     if (length(function.name2) && function.name != function.name2)
       warning("apparent conflict in name of link function")
 
-
     earg[["theta"]] <- theta  # New data
 
     earg[["inverse"]] <- TRUE  # New
-
-    return(do.call(what = function.name, args = earg))
-  }
+    return(do.call(function.name, earg))
+  }  # llink == 1
 
 
 
 
 
+  if (!is.matrix(theta) &&
+      length(theta) == length(earg))
+    theta <- rbind(theta)
 
+  vecTF <- link == special.fun 
+  Ans <- NULL
+  iii <- 1
+  while (iii <= llink) {
+    first.index <- last.index <- iii  # Ordinary case
+    special.case <- vecTF[iii]  # && sum(vecTF) < length(vecTF)
 
+    if (special.case) {
+      next.i <- iii+1
+      while (next.i <= llink) {
+        if (vecTF[next.i]) {
+          last.index <- next.i
+          next.i <- next.i + 1
+        } else {
+          break
+        }
+      }  # while
+    }  # special.case
 
-
- if (!is.matrix(theta) &&
-     length(theta) == length(earg))
-   theta <- rbind(theta)
-
-
-  ans <- NULL
-  for (iii in 1:llink) {
-    use.earg <- earg[[iii]]
+    iii <- iii + last.index - first.index + 1  # For next time
+    use.earg <- earg[[first.index]]
     use.earg[["inverse"]] <- TRUE  # New
-    use.earg[["theta"]] <- theta[, iii]  # New
-    use.function.name <- link[iii]
+    use.earg[["theta"]] <- theta[, first.index:last.index,
+                                 drop = FALSE]  # New
+    use.function.name <- link[first.index]  # "multilogitlink"
 
-    ans <- cbind(ans, do.call(what = use.function.name,
-                              args = use.earg))
-  }
+    if (first.index != last.index && special.case) {
+      adjusted.M <- last.index - first.index + 1
+      use.earg$M <- adjusted.M
+    }
+ 
+    Ans2 <- do.call(use.function.name, use.earg)
+    if (special.case && special.fun == "multilogitlink" &&
+        delete.coln)
+      Ans2 <- Ans2[, -use.earg$refLevel, drop = FALSE]
 
-  if (length(orig.earg) == ncol(ans) &&
+    Ans <- cbind(Ans, Ans2)
+  }  # while (iii <= llink)
+
+  if (length(orig.earg) == ncol(Ans) &&
       length(names(orig.earg)) > 0 &&
-      ncol(ans) > 0)
-    colnames(ans) <- names(orig.earg)
+      ncol(Ans) > 0)
+    colnames(Ans) <- names(orig.earg)
 
-  ans
-}
+  Ans
+}  # eta2theta
 
 
 
@@ -231,26 +257,8 @@
   earg[["short"]] <- short
 
 
-  do.call(link, args = earg)
-}
-
-
-
-
-if (FALSE)
- namesof <- function(theta,
-                     link = "identitylink",
-                     earg = list(tag = tag, short = short),
-                     tag = FALSE,
-                     short = TRUE) {
-
-
-  earg[["theta"]] <- as.character(theta)
-  earg[["tag"]] <- tag
-  earg[["short"]] <- short
-  do.call(link, args = earg)
-}
-
+  do.call(link, earg)
+}  # namesof
 
 
 
@@ -292,7 +300,7 @@ link2list <- function(link
 
 
   Big.list
-}
+}  # link2list
 
 
 
