@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2019 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2020 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -111,7 +111,8 @@ get.arg <- function(string) {
 
 
 
-tapplymat1 <- function(mat, function.arg = c("cumsum", "diff", "cumprod")) {
+tapplymat1 <-
+  function(mat, function.arg = c("cumsum", "diff", "cumprod")) {
 
 
   if (!missing(function.arg))
